@@ -47,6 +47,10 @@ OC.L10N.register(
     "Settings" : "Asetukset",
     "Enable RSS feed" : "Käytä RSS-syötettä",
     "No more events to load" : "Ei enempää tapahtumia ladattavaksi",
-    "Files" : "Tiedostot"
+    "Files" : "Tiedostot",
+    "Error loading activities" : "Virhe ladatessa toimia",
+    "No activities" : "Ei toimia",
+    "You are receiving this email because the following things happened at %s" : "Saat tämän viestin, koska kohteessa %s tapahtui seuraavaa",
+    "* %1$s - %2$s" : "* %1$s - %2$s"
 },
 "nplurals=2; plural=(n != 1);");
