@@ -2,17 +2,17 @@ OC.L10N.register(
     "activity",
     {
     "Activities" : "Atividades",
-    "An error occurred while loading activities" : "Ocorreu um erro durante o carregamento de atividades",
+    "An error occurred while loading activities" : "Ocorreu um erro ao carregar atividades",
     "No activity yet" : "Nenhuma atividade ainda",
     "Load more activities" : "Carregar mais atividades",
     "Copied!" : "Copiado!",
     "Not supported!" : "Não suportado!",
     "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
-    "{name} (invisible)" : "{name} (invisível)",
+    "{name} (invisible)" : "{nome} (invisível)",
     "{name} (restricted)" : "{name} (restrito)",
     "in {path}" : "em {path}",
-    "This stream will show events like additions, changes & shares" : "Este fluxo de dados vai mostrar eventos como aditamentos, alterações e compartilhamentos",
+    "This stream will show events like additions, changes & shares" : "Este stream vai mostrar eventos como aditamentos, alterações e compartilhamentos",
     "There are no events for this filter" : "Não há eventos para este filtro",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
@@ -21,10 +21,10 @@ OC.L10N.register(
     "Your settings have been updated." : "Suas configurações foram atualizadas.",
     "Settings have been updated." : "As configurações foram atualizadas.",
     "Mail" : "E-mail",
-    "Stream" : "Fluxo de dados",
+    "Stream" : "Stream",
     "All activities" : "Todas as atividades",
     "By others" : "Por outros",
-    "By you" : "Por você",
+    "By you" : "Por Você",
     "\"remote user\"" : "\"usuário remoto\"",
     "Hello %s" : "Olá %s",
     "Hello %s," : "Olá %s,",
@@ -37,16 +37,21 @@ OC.L10N.register(
     "Activity feed" : "Feed de atividade",
     "Configure the default activity settings for new users." : "Definir as configurações de atividade padrões para novos usuários.",
     "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escolher para quais atividades você quer receber uma notificação por e-mail e quais devem ser mostradas no fluxo de atividade do aplicativo.",
-    "List your own actions in the stream" : "Liste suas próprias ações no fluxo de dados",
+    "List your own actions in the stream" : "Liste suas próprias ações no stream",
     "Notify about your own actions via email" : "Notificar suas próprias ações por e-mail",
     "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
     "Send emails:" : "Enviar e-mails:",
     "Hourly" : "De hora em hora",
-    "Daily" : "Diáriamente",
+    "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
     "Settings" : "Configurações",
     "Enable RSS feed" : "Habilitar feed RSS",
     "No more events to load" : "Não há mais eventos para carregar",
-    "Files" : "Arquivos"
+    "Files" : "Arquivos",
+    "Error loading activities" : "Erro carregando atividades",
+    "No activities" : "Sem atividades",
+    "You are receiving this email because the following things happened at %s" : "Você está recebendo este e-mail porque as seguintes coisas aconteceram em %s",
+    "* %1$s - %2$s" : "* %1$s - %2$s",
+    "_* and %n more _::_* and %n more _" : ["* e mais %n","* e mais %n"]
 },
 "nplurals=2; plural=(n > 1);");
