@@ -65,11 +65,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
     "View in folder" : "Vis i mappe",
+    "Copied!" : "Kopieret",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
     "Path" : "Sti",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Gjort til foretrukken",
     "Favorite" : "Foretrukken",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
     "New folder" : "Ny Mappe",
     "Upload file" : "Upload fil",
     "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
@@ -84,6 +85,7 @@ OC.L10N.register(
     "Restored by {user}" : "Gendannet af {user}",
     "Renamed by {user}" : "Omdøbt af {user}",
     "Moved by {user}" : "Flyttet af {user}",
+    "\"remote user\"" : "\"ekstern bruger\"",
     "You created {file}" : "Du har oprettet {file}",
     "{user} created {file}" : "{user} oprettede {file}",
     "{file} was created in a public folder" : "{file} blev oprettet i en offentlig mappe",
@@ -100,9 +102,8 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "En fil er blevet tilføjet eller fjernet fra dine <strong>favoritter</strong>",
     "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong> eller <strong>omdøbt</strong>",
     "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
-    "A new file or folder has been <strong>deleted</strong>" : "En ny fil eller mappe er blevet <strong>slettet</strong>",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
-    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mappe er blevet <strong>gendannet</strong>",
+    "Unlimited" : "Ubegrænset",
     "Upload (max. %s)" : "Upload (max. %s)",
     "File handling" : "Filhåndtering",
     "Maximum upload size" : "Maksimal upload-størrelse",
@@ -110,6 +111,8 @@ OC.L10N.register(
     "Save" : "Gem",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det tage 5 minuter for ændringerne at blive udført.",
     "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
+    "%s of %s used" : "%s af %s brugt",
+    "%s used" : "%s brugt",
     "Settings" : "Indstillinger",
     "Show hidden files" : "Vis skjulte filer",
     "WebDAV" : "WebDAV",
@@ -141,6 +144,8 @@ OC.L10N.register(
     "Copy local link" : "Kopier lokalt link",
     "Folder" : "Mappe",
     "Upload" : "Upload",
+    "A new file or folder has been <strong>deleted</strong>" : "En ny fil eller mappe er blevet <strong>slettet</strong>",
+    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mappe er blevet <strong>gendannet</strong>",
     "No favorites" : "Ingen foretrukne"
 },
 "nplurals=2; plural=(n != 1);");
