@@ -53,7 +53,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
     "{dirs} and {files}" : "{dirs} y {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
-    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí.",
+    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
     "New" : "Nuevo",
     "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
@@ -65,12 +65,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
     "View in folder" : "Ver en carpeta",
+    "Copied!" : "¡Copiado!",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiae enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Agregado a Favoritos",
+    "Favorited" : "Agregado a favoritos",
     "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiae enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "New folder" : "Nueva carpeta",
+    "Upload file" : "Subir archivo",
     "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
     "Added to favorites" : "Agregado a favoritos",
     "Removed from favorites" : "Borrado de favoritos",
@@ -83,6 +85,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renombrado por {user}",
     "Moved by {user}" : "Movido por {user}",
+    "\"remote user\"" : "\"usuario remoto\"",
     "You created {file}" : "Ha creado {file}",
     "{user} created {file}" : "{user} ha creado {file}",
     "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
@@ -97,11 +100,12 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Ha movido {oldfile } a {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>.",
+    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
     "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
-    "A new file or folder has been <strong>deleted</strong>" : "Un nuevo archivo o carpeta ha sido <strong>eliminado</strong>.",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaiones acerca de la creación y cambios de sus <strong>archivos favoritos</strong><em>(Stream only)</em>",
-    "A new file or folder has been <strong>restored</strong>" : "Un nuevo archivo o carpeta ha sido <strong>restaurado</strong>.",
+    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
+    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaciones acerca de la creación y cambios de sus <strong>archivos favoritos</strong> <em>(solo flujos)</em>",
+    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
+    "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Subida (máx. %s)",
     "File handling" : "Administración de archivos",
     "Maximum upload size" : "Tamaño máximo de subida",
@@ -109,12 +113,14 @@ OC.L10N.register(
     "Save" : "Guardar",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar 5 minutos para que se realicen los cambios.",
     "Missing permissions to edit from here." : "Faltan permisos para poder editar desde aquí.",
+    "%s of %s used" : "%s de %s usado",
+    "%s used" : "usado %s",
     "Settings" : "Ajustes",
     "Show hidden files" : "Mostrar archivos ocultos",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Introduce esta dirección <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> en el cliente de ownCloud para acceder a tus archivos a través de él</a>",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">acceder tus archivos mediante WebDAV</a>",
     "No files in here" : "Aquí no hay archivos",
-    "Upload some content or sync with your devices!" : "Suba contenidos o sincronice sus dispositivos.",
+    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
     "No entries found in this folder" : "No hay entradas en esta carpeta",
     "Select all" : "Seleccionar todo",
     "Upload too large" : "Subida demasido grande",
@@ -140,6 +146,8 @@ OC.L10N.register(
     "Copy local link" : "Copiar enlace local",
     "Folder" : "Carpeta",
     "Upload" : "Subir",
+    "A new file or folder has been <strong>deleted</strong>" : "Un nuevo archivo o carpeta ha sido <strong>eliminado</strong>",
+    "A new file or folder has been <strong>restored</strong>" : "Un nuevo archivo o carpeta ha sido <strong>restaurado</strong>",
     "No favorites" : "No hay favoritos"
 },
 "nplurals=2; plural=(n != 1);");
