@@ -1,9 +1,9 @@
 OC.L10N.register(
     "files_external",
     {
-    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Henting av henvendelsessymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
-    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Henting av adgangssymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
-    "Please provide a valid app key and secret." : "Vær vennlig å oppgi gyldig appnøkkel og hemmelighet.",
+    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Henting av henvendelsessymboler mislyktes. Sjekk at programnøkkelen og hemmeligheten din stemmer. ",
+    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Henting av adgangssymboler mislyktes. Sjekk at programnøkkelen og hemmeligheten din stemmer.",
+    "Please provide a valid app key and secret." : "Oppgi gyldig programnøkkel og hemmelighet.",
     "Step 1 failed. Exception: %s" : "Steg 1 mislyktes. Unntak: %s",
     "Step 2 failed. Exception: %s" : "Steg 2 mislyktes. Unntak: %s",
     "External storages" : "Ekstern lagring",
@@ -24,13 +24,13 @@ OC.L10N.register(
     "Saving..." : "Lagrer...",
     "Save" : "Lagre",
     "Empty response from the server" : "Tomt svar fra tjeneren",
-    "Couldn't access. Please logout and login to activate this mount point" : "Fikk ikke tilgang. Logg ut og inn igjen for å aktivere dette oppkoblingspunktet.",
+    "Couldn't access. Please log out and in again to activate this mount point" : "Fikk ikke tilgang. Logg ut og inn igjen for å aktivere dette oppkoblingspunktet.",
     "Couldn't get the information from the remote server: {code} {type}" : "Kunne ikke få informasjon fra fjerntjeneren/ remote server: {code} {type}",
     "Couldn't get the list of external mount points: {type}" : "Klarte ikke å hente listen over eksterne oppkoblingspunkter: {type}",
     "There was an error with message: " : "Det oppstod en feil med melding: ",
     "External mount error" : "Ekstern oppkoblingsfeil",
     "external-storage" : "eksternlagring",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Klarte ikke å hente listen over oppkoblingspunkter for Windowsnettverks-disker: Tomt svar fra tjeneren",
+    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Klarte ikke å hente listen over oppkoblingspunkter for Windowsnettverks-disker: Tomt svar fra tjeneren",
     "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Noen av de oppsatte eksterne oppkoblingspunktene er ikke tilkoblet. Klikk på de røde raden(e) for mer informasjon.",
     "Please enter the credentials for the {mount} mount" : "Legg inn påloggingsdetaljer for {mount}",
     "Username" : "Brukernavn",
@@ -104,7 +104,7 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Tidsavbrudd for forespørsel (sekunder)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> Støtte for cURL i PHP er ikke aktivert eller installert. Oppkobling av %s er ikke mulig. Be systemadministratoren om å installere det.",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> FTP-støtte i PHP er ikke slått på eller installert. Kan ikke koble opp %s. Ta kontakt med systemadministratoren for å få dette installert.",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Vennligst spør din systemadministrator om å installere det.",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Spør din systemadministrator om å installere det.",
     "External storage support" : "Støtte for lagring eksternt",
     "No external storage configured" : "Eksternt lager er ikke konfigurert",
     "You can add external storages in the personal settings" : "Du kan legge til eksterne lagre i personlige innstillinger",
