@@ -24,27 +24,27 @@ OC.L10N.register(
     "Saving..." : "Сохранение...",
     "Save" : "Сохранить",
     "Empty response from the server" : "Пустой ответ от сервера",
-    "Couldn't access. Please logout and login to activate this mount point" : "Не удалось получить доступ. Пожалуйста, выйти и войдите чтобы активировать эту точку монтирования",
+    "Couldn't access. Please log out and in again to activate this mount point" : "Не удалось получить доступ. Для активации этой точки подключения выйдите и снова войдите в систему",
     "Couldn't get the information from the remote server: {code} {type}" : "Не удалось получить информацию с удалённого сервера: {code} {type}",
     "Couldn't get the list of external mount points: {type}" : "Не удалось получить список внешних точек монтирования: {type}",
     "There was an error with message: " : "Обнаружена ошибка с сообщением:",
     "External mount error" : "Ошибка внешнего монтирования",
     "external-storage" : "внешнее-хранилище",
-    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Не удалось получить список точек монтирования сетевых дисков Windows: пустой ответ от сервера",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Некоторые из настроенных внешних точек монтирования не подключены. Для получения дополнительной информации пожалуйста нажмите на красную строку(и)",
-    "Please enter the credentials for the {mount} mount" : "Пожалуйста укажите учетные данные для {mount}",
+    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Не удалось получить список точек подключения сетевых дисков Windows: пустой ответ от сервера",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Некоторые из настроенных внешних точек монтирования не подключены. Для получения дополнительной информации нажмите на красную строку(и)",
+    "Please enter the credentials for the {mount} mount" : "Укажите учётные данные для {mount}",
     "Username" : "Имя пользователя",
     "Password" : "Пароль",
-    "Credentials saved" : "Учетные данные сохранены",
-    "Credentials saving failed" : "Ошибка сохранения учетных данных",
-    "Credentials required" : "Требуются учетные данные",
+    "Credentials saved" : "Учётные данные сохранены",
+    "Credentials saving failed" : "Ошибка сохранения учётных данных",
+    "Credentials required" : "Требуются учётные данные",
     "Storage with ID \"%d\" not found" : "Хранилище с идентификатором «%d» не найдено",
     "Invalid backend or authentication mechanism class" : "Некорректный механизм авторизации или бэкенд",
     "Invalid mount point" : "Неправильная точка входа",
     "Objectstore forbidden" : "Хранение объектов запрещено",
-    "Invalid storage backend \"%s\"" : "Неверный бэкенд хранилища \"%s\"",
-    "Not permitted to use backend \"%s\"" : "Не допускается использование бэкенда \"%s\"",
-    "Not permitted to use authentication mechanism \"%s\"" : "Не допускается использование механизма авторизации \"%s\"",
+    "Invalid storage backend \"%s\"" : "Неверный бэкенд хранилища «%s»",
+    "Not permitted to use backend \"%s\"" : "Не допускается использование бэкенда «%s»",
+    "Not permitted to use authentication mechanism \"%s\"" : "Не допускается использование механизма авторизации «%s»",
     "Unsatisfied backend parameters" : "Недопустимые настройки бэкенда",
     "Unsatisfied authentication mechanism parameters" : "Недопустимые настройки механизма авторизации",
     "Insufficient data: %s" : "Недостаточно данных: %s",
@@ -65,10 +65,10 @@ OC.L10N.register(
     "Identity endpoint URL" : "Удостоверение конечной точки URL",
     "Rackspace" : "Rackspace",
     "API key" : "Ключ API",
-    "Global credentials" : "Глобальные учетные данные",
-    "Log-in credentials, save in database" : "Учетные данные, хранить в базе данных",
+    "Global credentials" : "Глобальные учётные данные",
+    "Log-in credentials, save in database" : "Учётные данные, хранить в базе данных",
     "Username and password" : "Имя пользователя и пароль",
-    "Log-in credentials, save in session" : "Учетные данные, хранить в сессии",
+    "Log-in credentials, save in session" : "Учётные данные, хранить в сессии",
     "User entered, store in database" : "Пользователь авторизован, сохранить в базе данных",
     "RSA public key" : "Открытый ключ RSA",
     "Public key" : "Открытый ключ",
@@ -80,7 +80,7 @@ OC.L10N.register(
     "Enable SSL" : "Включить SSL",
     "Enable Path Style" : "Включить стиль пути",
     "WebDAV" : "WebDAV",
-    "URL" : "Ссылка",
+    "URL" : "URL",
     "Remote subfolder" : "Удаленный подкаталог",
     "Secure https://" : "Безопасный https://",
     "Dropbox" : "Dropbox",
@@ -89,13 +89,13 @@ OC.L10N.register(
     "Secure ftps://" : "Защищённый ftps://",
     "Google Drive" : "Google Drive",
     "Local" : "Локально",
-    "Location" : "Местоположение",
+    "Location" : "Расположение",
     "Nextcloud" : "Nextcloud",
     "SFTP" : "SFTP",
     "Root" : "Корневой каталог",
     "SFTP with secret key login" : "SFTP с помощью секретного ключа",
     "SMB / CIFS" : "SMB / CIFS",
-    "Share" : "Общий доступ",
+    "Share" : "Общий ресурс",
     "Domain" : "Домен",
     "SMB / CIFS using OC login" : "SMB / CIFS с ипользованием логина OC",
     "Username as share" : "Имя пользователя в качестве имени общего ресурса",
@@ -104,10 +104,10 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Таймаут запроса (в секундах)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддержка cURL в PHP не включена и/или не установлена, монтирование %s невозможно. Обратитесь к вашему системному администратору.",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Поддержка FTP в PHP не включена и/или не установлена, монтирование %s невозможно. Обратитесь к вашему системному администратору.",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" не установлен, монтирование %s невозможно. Обратитесь к вашему системному администратору.",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "«%s» не установлен, монтирование %s невозможно. Обратитесь к вашему системному администратору.",
     "External storage support" : "Поддержка внешних хранилищ",
-    "No external storage configured" : "Нет внешних хранилищ",
-    "You can add external storages in the personal settings" : "Вы можете добавить внешние накопители в личных настройках",
+    "No external storage configured" : "Нет настроенных внешних хранилищ",
+    "You can add external storages in the personal settings" : "Вы можете добавить внешние хранилища в личных настройках",
     "Name" : "Имя",
     "Storage type" : "Тип хранилища",
     "Scope" : "Область",
@@ -116,7 +116,7 @@ OC.L10N.register(
     "Enable sharing" : "Включить общий доступ",
     "Check for changes" : "Проверять изменения",
     "Never" : "Никогда",
-    "Once every direct access" : "Один раз при прямом доступе",
+    "Once every direct access" : "Каждый раз при прямом доступе",
     "Folder name" : "Имя каталога",
     "External storage" : "Внешнее хранилище",
     "Authentication" : "Авторизация",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Delete" : "Удалить",
     "Allow users to mount external storage" : "Разрешить пользователями монтировать внешние накопители",
     "Allow users to mount the following external storage" : "Разрешить пользователям монтировать следующие сервисы хранения данных",
-    "Storage with id \"%i\" not found" : "Хранилище с идентификатором \"%i\" не найдено",
-    "Storage with id \"%i\" is not user editable" : "Пользователь не может редактировать хранилище \"%i\""
+    "Storage with id \"%i\" not found" : "Хранилище с идентификатором «%i» не найдено",
+    "Storage with id \"%i\" is not user editable" : "Пользователь не может редактировать хранилище «%i»"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
