@@ -14,7 +14,7 @@ OC.L10N.register(
     "No compatible server found at {remote}" : "Nenhum servidor compativel encontrado em {remote}",
     "Invalid server URL" : "URL do servidor inválida",
     "Failed to add the public link to your Nextcloud" : "Ocorreu uma falha ao adicionar o link público ao seu Nextcloud",
-    "Share" : "Compartilhamento",
+    "Share" : "Compartilhar",
     "No expiration date set" : "Nenhuma data de expiração definida",
     "Shared by" : "Compartilhado por",
     "Sharing" : "Compartilhando",
@@ -32,7 +32,7 @@ OC.L10N.register(
     "{actor} shared {file} with group {group}" : "{actor} compartilhou {file} com o grupo {group}",
     "{actor} removed group {group} from {file}" : "{actor} excluiu o grupo {group} de {file}",
     "Shared as public link" : "Compartilhado como um link publico",
-    "Removed public link" : "Excluido o link público",
+    "Removed public link" : "Excluído o link público",
     "Public link expired" : "O link público expirou",
     "{actor} shared as public link" : "{actor} compartilhou como um link publico",
     "{actor} removed public link" : "{actor} excluiu o link publico",
@@ -44,7 +44,7 @@ OC.L10N.register(
     "{actor} removed public link for {file}" : "{actor} excluiu o link publico de {file}",
     "Public link of {actor} for {file} expired" : "O link público de {actor} para {file} expirou",
     "{user} accepted the remote share" : "{user} aceitou o compartilhamento remoto",
-    "{user} declined the remote share" : "{user} declinou do compartilhamento remoto",
+    "{user} declined the remote share" : "{user} declinou o compartilhamento remoto",
     "You received a new remote share {file} from {user}" : "Você recebeu um novo compartilhamento remoto {file} de {user}",
     "{user} accepted the remote share of {file}" : "{user} aceitou o compartilhamento remoto de {file}",
     "{user} declined the remote share of {file}" : "{user} declinou do compartilhamento remoto de {file}",
@@ -77,7 +77,7 @@ OC.L10N.register(
     "Public link sharing is disabled by the administrator" : "O compartilhamento por link público foi desativado pelo administrador",
     "Public upload disabled by the administrator" : "O envio público foi desativado pelo administrador",
     "Public upload is only possible for publicly shared folders" : "O envio público só é possível para pastas compartilhadas publicamente",
-    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser YYYY-MM-DD",
+    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
     "Sharing %s failed because the back end does not allow shares from type %s" : "O compartilhando %s falhou porque o serviço não permite ações de tipo %s",
     "You cannot share to a Circle if the app is not enabled" : "Você não pode compartilhar para um círculo se o aplicativo não está habilitado",
     "Please specify a valid circle" : "Por favor especifique um círculo válido",
@@ -103,6 +103,7 @@ OC.L10N.register(
     "the link expired" : "o link expirou",
     "sharing is disabled" : "o compartilhamento está desativado",
     "For more info, please ask the person who sent this link." : "Para mais informações, pergunte à pessoa que lhe enviou o link.",
+    "shared by %s" : "compartilhado por %s",
     "Add to your Nextcloud" : "Adicionar ao seu Nextcloud",
     "Download" : "Baixar",
     "Download %s" : "Baixar %s",
