@@ -4,25 +4,24 @@ OC.L10N.register(
     "Gallery" : "Galerie",
     "There was a problem reading files from this album" : "Es gab ein Problem Dateien aus diesem Album zu lesen",
     "Aborting preview. Could not find the file" : "Die Vorschau wird abgebrochen. Die Datei konnte nicht gefunden werden",
-    "Could not move \"{file}\", target exists" : "Die Datei konnte nicht verschoben werden \"{file}\", da die Datei im Zielordner bereits existiert",
-    "Could not move \"{file}\"" : "Die Datei konnte nicht verschoben werden \"{file}\"",
+    "Could not move \"{file}\", target exists" : "Konnte \"{file}\" nicht verschieben, Ziel existiert bereits",
+    "Could not move \"{file}\"" : "Konnte \"{file}\" nicht verschieben ",
     "No compatible server found at {remote}" : "Keinen kompatiblen Server unter {remote} gefunden",
     "Invalid server url" : "Ungültige Server-URL",
-    "Gallery view" : "Galerie-Ansicht",
     "Could not load the description" : "Die Beschreibung konnte nicht geladen werden",
     "Could not load the description: " : "Die Beschreibung konnte nicht geladen werden:",
-    "Copyright" : "Copyright",
-    "Could not load the copyright notice: " : "Der Urheberrechtsschutz konnte nicht geladen werden:",
-    "Copyright notice" : "Urheberrechtsschutz",
-    "Link to copyright document" : "Link zum Uhrheberrechts-Dokument",
-    "This application may not work properly on your browser." : "Diese Anwendung könnte auf Ihrem Browser nicht einwandfrei funktionieren",
+    "Copyright" : "Urheberrecht",
+    "Could not load the copyright notice: " : "Der Urheberrechtshinweis konnte nicht geladen werden:",
+    "Copyright notice" : "Urheberrechtshinweis",
+    "Link to copyright document" : "Link zum Urheberrechts-Dokument",
+    "This application may not work properly on your browser." : "Diese Anwendung könnte mit Ihrem Browser nicht einwandfrei funktionieren",
     "For an improved experience, please install one of the following alternatives" : "Für eine bessere Erfahrung installieren Sie bitte eine der folgenden Alternativen",
     "Your browser is not supported!" : "Ihr Browser wird nicht unterstützt!",
-    "please install one of the following alternatives" : "Bitte installieren Sie eine der folgenden Alternativen",
+    "please install one of the following alternatives" : "Bitte eine der folgenden Alternativen installieren",
     "Album cannot be shown" : "Album kann nicht angezeigt werden.",
-    "No media files found" : "Es wurden keine Medien Dateien gefunden",
-    "Upload pictures in the files app to display them here" : "Laden Sie Bilder in der Dateien App hoch, um sie hier angezeigt zu bekommen.",
-    "Upload new files via drag and drop or by using the [+] button above" : "Hochladen neuer Dateien mittels Drag&Drop oder mit der [+]-Schaltfläche oben",
+    "No media files found" : "Keine Mediendateien gefunden.",
+    "Upload pictures in the Files app to display them here" : "Laden Sie Bilder in der Dateien-App hoch, damit diese hier angezeigt werden. ",
+    "Upload new files via drag and drop or by using the [+] button above" : "Lade neue Dateien via Drag and Drop oder mit der [+]-Schaltfläche hoch.",
     "Configuration error" : "Konfigurationsfehler",
     "New" : "Neu",
     "Hide Album" : "Album ausblenden",
@@ -37,17 +36,18 @@ OC.L10N.register(
     "Download" : "Herunterladen",
     "Toggle background" : "Hintergrund umschalten",
     "Delete" : "Löschen",
-    "Could not create file \"{file}\" because it already exists" : "Die Datei konnte nicht erstellt werden \"{file}\", da diese bereits existiert",
+    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert",
     "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
-    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
+    "\"{name}\" is an invalid file name." : "\"{name}“ ist kein gültiger Dateiname.",
     "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}“ ist kein erlaubter Dateityp ",
     "Upload" : "Hochladen",
     "Error" : "Fehler",
     "Error while sharing" : "Fehler beim Teilen",
     "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
-    "Error while changing permissions" : "Fehler bei der Änderung der Rechte",
-    "Shared with you and the group {group} by {owner}" : "Von {owner} mit Ihnen und der Gruppe {group} geteilt.",
-    "Shared with you by {owner}" : "Von {owner} mit Ihnen geteilt.",
+    "Error while changing permissions" : "Fehler beim Ändern der Rechte",
+    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Ihnen und der Gruppe {group} geteilt.",
+    "Shared with you by {owner}" : "{owner} hat dies mit Ihnen geteilt",
     "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
     "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder externen Benutzern teilen…",
     "Share" : "Teilen",
@@ -57,21 +57,24 @@ OC.L10N.register(
     "Link" : "Link",
     "Password protect" : "Passwortschutz",
     "Password" : "Passwort",
-    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
+    "Choose a password for the public link" : "Passwort für den öffentlichen Link eingeben",
     "Allow editing" : "Bearbeitung erlauben",
-    "Email link to person" : "Link per E-Mail verschicken",
+    "Email link to person" : "Link per E-Mail versenden",
     "Send" : "Senden",
     "Set expiration date" : "Ein Ablaufdatum setzen",
     "Expiration" : "Ablaufdatum",
     "Expiration date" : "Ablaufdatum",
+    "This list is maybe truncated - please refine your search term to see more results." : "Die Liste ist unter Umständen gekürzt - Bitte verfeinern Sie Ihre Suche um mehr Ergebnisse zu erhalten. ",
+    "No users or groups found for {search}" : "Keine Benutzer oder Gruppen gefunden für {search}",
+    "No users found for {search}" : "Keine Benutzer für {search} gefunden",
     "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuchen Sie es noch einmal",
     "Adding user..." : "Benutzer wird hinzugefügt…",
     "group" : "Gruppe",
     "remote" : "Externe Freigabe",
-    "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
+    "Resharing is not allowed" : "Weiterteilen ist nicht erlaubt",
     "Error while retrieving shares" : "Fehler beim Abrufen der Freigaben",
     "Unshare" : "Freigabe aufheben",
-    "notify by email" : "per E-Mail benachrichtigen",
+    "notify by email" : "Per E-Mail benachrichtigen",
     "can share" : "kann teilen",
     "can edit" : "kann bearbeiten",
     "access control" : "Zugriffskontrolle",
@@ -84,33 +87,33 @@ OC.L10N.register(
     "Sending ..." : "Senden…",
     "Email sent" : "E-Mail gesendet",
     "Warning" : "Warnung",
-    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
+    "This share is password-protected" : "Freigabe ist passwortgeschützt",
     "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
     "Sort by date" : "Nach Datum ordnen",
     "Sort by name" : "Nach Name ordnen",
-    "Cancel upload" : "Upload abbrechen",
+    "Cancel upload" : "Hochladen abbrechen",
     "Album information" : "Albuminformation",
     "File list" : "Dateiliste",
-    "Sorry, this file could not be found." : "Entschuldigen Sie, diese Datei wurde nicht gefunden.",
+    "Sorry, this file could not be found." : "Diese Datei wurde leider nicht gefunden.",
     "Reasons might be:" : "Gründe könnten sein:",
-    "the wrong file ID was provided" : "die falsche Datei ID wurde übermittelt",
+    "the wrong file ID was provided" : "Falsche Datei-ID wurde angegeben",
     "the file was removed" : "Die Datei wurde entfernt",
-    "the file is corrupt" : "Die Datei ist korrupt",
+    "the file is corrupt" : "Die Datei ist beschädigt",
     "the encryption key is missing" : "Der Verschlüsselungsschlüssel fehlt",
-    "Here is the error message returned by the server: " : "Diese Fehler Meldung is vom Server zurück gekommen:",
+    "Here is the error message returned by the server: " : "Diese Fehlermeldung wurde vom Server zurückgegeben:",
     "For more information, please contact your friendly Nextcloud administrator." : "Für weitere Informationen kontaktieren Sie bitte Ihren freundlichen Nextcloud-Administrator.",
-    "Sorry, but the server could not fulfill your request." : "Entschuldigen Sie, aber der Server kann Ihre Anfrage nicht ausführen.",
-    "Possible reasons for the problem:" : "Ein möglicher Grund für dieses Proble:",
-    "a conflicting app was installed" : "eine widersprüchliche App wurde installiert",
-    "a required component is missing or was disconnected" : "eine erforderliche Komponente fehlt oder wurde getrennt",
-    "the filesystem is not readable" : "Das Dateisystem konnte nicht gelesen werden",
-    "For more information, please contact your friendly ownCloud administrator." : "Für mehr Informationen kontaktieren Sie bitte Ihren freundlichen ownCloud Administrator.",
+    "Sorry, but the server could not fulfill your request." : "Der Server kann Ihre Anfrage leider nicht ausführen.",
+    "Possible reasons for the problem:" : "Mögliche Gründe für das Problem:",
+    "a conflicting app was installed" : "Eine konfliktträchtige App wurde installiert",
+    "a required component is missing or was disconnected" : "Eine erforderliche Komponente fehlt oder wurde getrennt",
+    "the filesystem is not readable" : "Das Dateisystem ist nicht lesbar",
     "Sorry, this link doesn't seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
     "the item was removed" : "Das Element wurde entfernt",
     "the link has expired" : "Der Link ist abgelaufen",
     "sharing is disabled" : "Teilen ist deaktiviert",
     "For more information, please ask the person who has sent you this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
     "Add to your Nextcloud" : "Zu Ihrer Nextcloud hinzufügen",
-    "Picture view" : "Bildansicht"
+    "Picture view" : "Bildansicht",
+    "Gallery view" : "Galerieansicht"
 },
 "nplurals=2; plural=(n != 1);");
