@@ -1,16 +1,16 @@
 OC.L10N.register(
     "password_policy",
     {
-    "Password need to be at least %s characters long" : "La contraseña precisa ser de polo menos %s caráuteres de llargor",
-    "Password need to contain at least one lower case character and one upper case character." : "La contraseña precisa tener polo menos una mayúscula y minúscula.",
-    "Password need to contain at least one numeric character." : "La contraseña precisa contener polo menos un caráuter numbéricu.",
-    "Password need to contain at least one special character." : "La contraseña precisa contener polo menos un caráuter especial.",
-    "Password is within the 1,000,000 most common passwords. Please choose another one." : "La contraseña ta dientro de les 1.000.000 más comunes. Escueyi otra, por favor.",
     "Password policy" : "Política de contraseñes",
     "Minimal length" : "Llargor mínimu",
     "Forbid common passwords" : "Contraseñes prohibíes comunes",
     "Enforce upper and lower case characters" : "Obligar mayúscules y minúscules",
     "Enforce numeric characters" : "Obligar caráuteres numbéricos",
-    "Enforce special characters" : "Obligar caráuteres especiales"
+    "Enforce special characters" : "Obligar caráuteres especiales",
+    "Password need to be at least %s characters long" : "La contraseña precisa ser de polo menos %s caráuteres de llargor",
+    "Password need to contain at least one lower case character and one upper case character." : "La contraseña precisa tener polo menos una mayúscula y minúscula.",
+    "Password need to contain at least one numeric character." : "La contraseña precisa contener polo menos un caráuter numbéricu.",
+    "Password need to contain at least one special character." : "La contraseña precisa contener polo menos un caráuter especial.",
+    "Password is within the 1,000,000 most common passwords. Please choose another one." : "La contraseña ta dientro de les 1.000.000 más comunes. Escueyi otra, por favor."
 },
 "nplurals=2; plural=(n != 1);");
