@@ -13,8 +13,17 @@ OC.L10N.register(
     "Failed to send share by E-mail" : "Kunne ikke dele via e-mail",
     "%s shared »%s« with you" : "%s delt »%s« med dig",
     "%s shared »%s« with you on behalf of %s" : "%s delte »%s« med dig for %s",
-    "Failed to create the E-mail" : "Oprettelse af e-mail mislykkedes",
+    "%s shared »%s« with you." : "%s delte »%s« med dig.",
+    "%s shared »%s« with you on behalf of %s." : "%s delte »%s« med dig på vegne af %s.",
+    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
+    "Open »%s«" : "Åbn »%s«",
+    "Password to access »%s« shared to you by %s" : "Kodeord for adgang til »%s« delt med dig af %s",
+    "Password to access »%s«" : "Kodeord for adgang til »%s«",
+    "It is protected with the following password: %s" : "Det er beskyttet af følgende kodeord: %s",
     "Could not find share" : "Kan ikke finde deling",
+    "Share by mail" : "Delt med mail",
+    "Send password by mail" : "Send kodeord på mail",
+    "Failed to create the E-mail" : "Oprettelse af e-mail mislykkedes",
     "Hey there,\n\n%s shared »%s« with you on behalf of %s.\n\n%s\n\n" : "Hej,\n\n%s delte »%s« med dig, for %s.\n\n%s\n\n",
     "Hey there,\n\n%s shared »%s« with you.\n\n%s\n\n" : "Hey there,\n\n%s delte »%s« med dig.\n\n%s\n\n",
     "Cheers!" : "Hej!",
