@@ -10,12 +10,10 @@ OC.L10N.register(
     "If you regenerate backup codes, you automatically invalidate old codes." : "При перевыпуске резервных кодов, старые автоматически становятся недействительными.",
     "An error occurred while generating your backup codes" : "Произошла ошибка при создании резервных кодов",
     "Nextcloud backup codes" : "Резервные коды Nextcloud",
-    "Two-factor authentication" : "Двухфакторная аутентификация",
-    "You successfully logged in using two-factor authentication (%1$s)" : "Вы успешно вошли в систему используя двухфакторную аутентификацию (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "Сбой при попытке входа с использованием двухфакторной аутентификации (%1$s)",
     "You created two-factor backup codes for your account" : "Вы создали двухфакторные резервные коды для своего аккаунта",
     "Backup code" : "Резервный код",
     "Use backup code" : "Использовать резервный код",
+    "Two factor backup codes" : "Второй фактор — резервные коды",
     "Second-factor backup codes" : "Резервные коды двухфакторной аутентификации"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
