@@ -7,10 +7,12 @@ OC.L10N.register(
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna. Sjá %s",
     "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Skrám forritsins %$1s var ekki rétt skipt út. Gakktu úr skugga um að þetta sé útgáfa sem sé samhæfð útgáfu vefþjónsins.",
     "Sample configuration detected" : "Fann sýnisuppsetningu",
+    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Komið hefur í ljós að sýniuppsetningin var afrituð. Þetta getur skemmt uppsetninguna og er ekki stutt. Endilega lestu hjálparskjölin áður en þú gerir breytingar á config.php",
     "%1$s and %2$s" : "%1$s og %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
+    "Education Edition" : "Kennsluútgáfa",
     "Enterprise bundle" : "Fyrirtækjavöndull",
     "Groupware bundle" : "Hópvinnsluvöndull",
     "Social sharing bundle" : "Deilivöndull fyrir samfélagsmiðla",
@@ -49,10 +51,9 @@ OC.L10N.register(
     "This is an automatically sent email, please do not reply." : "Þetta er sjálfvirk tölvupóstsending, ekki svara þessu.",
     "Help" : "Hjálp",
     "Apps" : "Forrit",
-    "Personal" : "Einka",
+    "Settings" : "Stillingar",
     "Log out" : "Skrá út",
     "Users" : "Notendur",
-    "Admin" : "Stjórnun",
     "APCu" : "APCu",
     "Redis" : "Redis",
     "Basic settings" : "Grunnstillingar",
@@ -61,6 +62,13 @@ OC.L10N.register(
     "Encryption" : "Dulritun",
     "Additional settings" : "Valfrjálsar stillingar",
     "Tips & tricks" : "Ábendingar og góð ráð",
+    "Personal info" : "Persónulegar upplýsingar",
+    "Sync clients" : "Samstilla biðlara",
+    "Unlimited" : "Ótakmarkað",
+    "__language_name__" : "Íslenska",
+    "Verifying" : "Sannreyni",
+    "Verifying …" : "Sannreyni …",
+    "Verify" : "Sannreyna",
     "%s enter the database username and name." : "%s settu inn notandanafn og nafn á gagnagrunni.",
     "%s enter the database username." : "%s settu inn notandanafn í gagnagrunni.",
     "%s enter the database name." : "%s settu inn nafn á gagnagrunni.",
@@ -74,6 +82,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Notandanafn eða lykilorð PostgreSQL er ekki gilt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X er ekki stutt og %s mun ekki vinna eðlilega á þessu stýrikerfi. Notaðu þetta því á þína eigin ábyrgð! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Fyrir bestu útkomu ættirðu að íhuga að nota GNU/Linux þjón í staðinn.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Það lítur út eins og þessi %s uppsetning sé að keyra á 32-bita PHP umhverfi og að open_basedir hafi verið stillt í php.ini. Þetta mun valda vandamálum með skrár stærri en 4 GB og er stranglega mælt gegn því að þetta sé gert.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjarlægðu stillinguna open_basedir úr php.ini eða skiptu yfir í 64-bita PHP.",
     "Set an admin username." : "Stilltu notandanafn kerfisstjóra.",
     "Set an admin password." : "Stilltu lykilorð kerfisstjóra.",
     "Can't create or write into the data directory %s" : "Gat ekki búið til eða skrifað í gagnamöppuna %s",
@@ -98,16 +108,25 @@ OC.L10N.register(
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Get ekki stillt gildistímann. Sameignir geta ekki runnið út síðar en %s eftir að þeim hefur verið deilt",
     "Cannot set expiration date. Expiration date is in the past" : "Get ekki stillt gildistímann. Gildistíminn er þegar runninn út",
     "Cannot clear expiration date. Shares are required to have an expiration date." : "Get ekki hreinsað út gildistímann. Ætlast er til þess að sameignir hafi ákveðinn gildistíma.",
+    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Deilingarbakendinn %s verður að vera settur upp fyrir viðmótið OCP\\Share_Backend",
     "Sharing backend %s not found" : "Deilingarbakendinn %s fannst ekki",
     "Sharing backend for %s not found" : "Deilingarbakendi fyrir %s fannst ekki",
     "Sharing failed, because the user %s is the original sharer" : "Deiling mistókst, því notandinn %s er upprunalegur deilandi",
+    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deiling %s mistókst, því heimildirnar eru rétthærri en heimildir til handa %s",
     "Sharing %s failed, because resharing is not allowed" : "Deiling %s mistókst, því endurdeiling er ekki leyfð",
+    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deiling %s mistókst, því bakvinnslukerfið fyrir %s fann ekki upptök þess",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deiling %s mistókst, því skráin fannst ekki í skyndiminni skráa",
-    "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
-    "Files can't be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
-    "Files can't be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
+    "Can’t increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
+    "Files can’t be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
+    "Files can’t be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
     "Expiration date is in the past" : "Gildistíminn er þegar runninn út",
-    "Cannot set expiration date more than %s days in the future" : "Ekki er hægt að setja lokadagsetningu meira en %s daga fram í tímann",
+    "Can’t set expiration date more than %s days in the future" : "Ekki er hægt að setja lokadagsetningu meira en %s daga fram í tímann",
+    "%s shared »%s« with you" : "%s deildi »%s« með þér",
+    "%s shared »%s« with you." : "%s deildi »%s« með þér.",
+    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
+    "Open »%s«" : "Opna »%s«",
+    "%s via %s" : "%s með %s",
+    "The requested share does not exist anymore" : "Umbeðin sameign er ekki lengur til",
     "Could not find category \"%s\"" : "Fann ekki flokkinn \"%s\"",
     "Sunday" : "Sunnudagur",
     "Monday" : "Mánudagur",
@@ -178,6 +197,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í forritamöppuna með því að gera forritabúðina óvirka í stillingaskránni. Sjá %s",
     "Cannot create \"data\" directory" : "Get ekki búið til \"data\" möppu",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Sjá %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Heimildir er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Sjá %s",
     "Setting locale to %s failed" : "Mistókst að setja upp staðfærsluna %s",
     "Please install one of these locales on your system and restart your webserver." : "Settu upp eina af þessum staðfærslum og endurræstu vefþjóninn.",
     "Please ask your server administrator to install the module." : "Biddu kerfisstjórann þinn um að setja eininguna upp.",
@@ -194,11 +214,12 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Biddu kerfisstjórann þinn um að endurræsa vefþjóninn.",
     "PostgreSQL >= 9 required" : "Krefst PostgreSQL >= 9",
     "Please upgrade your database version" : "Uppfærðu útgáfu gagnagrunnsins",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar.",
     "Your data directory is readable by other users" : "Gagnamappn þín er lesanleg fyrir aðra notendur",
     "Your data directory must be an absolute path" : "Gagnamappan þín verður að vera með algilda slóð",
     "Check the value of \"datadirectory\" in your configuration" : "Athugaðu gildi \"datadirectory\" í uppsetningunni þinni",
     "Your data directory is invalid" : "Gagnamappan þín er ógild",
-    "Please check that the data directory contains a file \".ocdata\" in its root." : "Athugaðu hvort gagnamappan innihaldi skrá með heitinu \".ocdata\" í rót hennar.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Gakktu úr skugga um að til staðar sé skrá með heitinu \".ocdata\" í rót gagnageymslunnar.",
     "Could not obtain lock type %d on \"%s\"." : "Gat ekki fengið læsingu af gerðinni %d á \"%s\".",
     "Storage unauthorized. %s" : "Gagnageymsla ekki auðkennd. %s",
     "Storage incomplete configuration. %s" : "Ófullgerð uppsetning gagnageymslu. %s",
@@ -209,14 +230,19 @@ OC.L10N.register(
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Eining með auðkenni: %s er ekki til. Virkjaðu hana í forritastillingum eða hafðu samband við kerfisstjóra.",
     "Server settings" : "Stillingar þjóns",
     "You need to enter either an existing account or the administrator." : "Þú verður að setja inn fyrirliggjandi notandaaðgang eða kerfisstjóra.",
-    "%s shared »%s« with you" : "%s deildi »%s« með þér",
-    "%s via %s" : "%s með %s",
+    "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
+    "Files can't be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
+    "Files can't be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
+    "Cannot set expiration date more than %s days in the future" : "Ekki er hægt að setja lokadagsetningu meira en %s daga fram í tímann",
+    "Personal" : "Einka",
+    "Admin" : "Stjórnun",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Þetta er venjulega hægt að laga ef %sgefur vefþjóninum skrifréttindi í forritamöppuna%s eða gerir forritabúðina óvirka í stillingaskránni.",
     "Cannot create \"data\" directory (%s)" : "Get ekki búið til \"data\" möppu (%s)",
     "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Þetta er venjulega hægt að laga ef <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">gefur vefþjóninum skrifréttindi í rótarmöppuna </a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Heimildir er venjulega hægt að laga ef %sgefur vefþjóninum skrifréttindi í rótarmöppuna %s.",
     "Data directory (%s) is readable by other users" : "Gagnamappa (%s) er lesanleg fyrir aðra notendur",
     "Data directory (%s) must be an absolute path" : "Gagnamappan (%s) verður að vera algild slóð",
-    "Data directory (%s) is invalid" : "Gagnamappa (%s) er ógild"
+    "Data directory (%s) is invalid" : "Gagnamappa (%s) er ógild",
+    "Please check that the data directory contains a file \".ocdata\" in its root." : "Athugaðu hvort gagnamappan innihaldi skrá með heitinu \".ocdata\" í rót hennar."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
