@@ -94,7 +94,7 @@ class CacheJail extends CacheWrapper {
 	 * get the stored metadata of a file or folder
 	 *
 	 * @param string /int $file
-	 * @return array|false
+	 * @return ICacheEntry|false
 	 */
 	public function get($file) {
 		if (is_string($file) or $file == '') {
@@ -175,6 +175,16 @@ class CacheJail extends CacheWrapper {
 		$this->getCache()->move($this->getSourcePath($source), $this->getSourcePath($target));
 	}
 
+	/**
+	 * Get the storage id and path needed for a move
+	 *
+	 * @param string $path
+	 * @return array [$storageId, $internalPath]
+	 */
+	protected function getMoveInfo($path) {
+		return [$this->getNumericStorageId(), $this->getSourcePath($path)];
+	}
+
 	/**
 	 * remove all entries for files that are stored on the storage from the cache
 	 */
