@@ -38,7 +38,6 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
     "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
-    "Invalid request" : "Ógild fyrirspurn",
     "Invalid mail address" : "Ógilt tölvupóstfang",
     "No valid group selected" : "Enginn gildur hópur valinn",
     "A user with that name already exists." : "Nú þegar til notandi með þetta nafn.",
@@ -102,8 +101,8 @@ OC.L10N.register(
     "Enable" : "Virkja",
     "Enabling app …" : "Virkja forrit …",
     "Error while enabling app" : "Villa við að virkja forrit",
-    "Error: this app cannot be enabled because it makes the server unstable" : "Villa: ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan",
-    "Error: could not disable broken app" : "Villa: gat ekki gert bilaða forritið óvirkt",
+    "Error: This app can not be enabled because it makes the server unstable" : "Villa: ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan.",
+    "Error: Could not disable broken app" : "Villa: gat ekki gert bilaða forritið óvirkt",
     "Error while disabling broken app" : "Villa við að gera bilaða forritið óvirkt",
     "Updating...." : "Uppfæri...",
     "Error while updating app" : "Villa við að uppfæra forrit",
@@ -153,6 +152,7 @@ OC.L10N.register(
     "Will be synced to a global and public address book" : "Verður samstillt víðværri og opinberri vistfangaskrá",
     "Verify" : "Sannreyna",
     "Verifying …" : "Sannreyni …",
+    "An error occured while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
     "Select a profile picture" : "Veldu einkennismynd",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
@@ -165,6 +165,7 @@ OC.L10N.register(
     "A valid group name must be provided" : "Skráðu inn gilt heiti á hópi",
     "deleted {groupName}" : "eyddi {groupName}",
     "undo" : "afturkalla",
+    "{size} used" : "{size} notað",
     "never" : "aldrei",
     "deleted {userName}" : "eyddi {userName}",
     "No user found for <strong>{pattern}</strong>" : "Enginn notandi fannst fyrir <strong>{pattern}</strong>",
@@ -181,13 +182,34 @@ OC.L10N.register(
     "Error creating user: {message}" : "Villa við að búa til notanda: {message}",
     "A valid password must be provided" : "Skráðu inn gilt lykilorð",
     "A valid email must be provided" : "Skráðu inn gilt tölvupóstfang",
-    "__language_name__" : "Íslenska",
-    "Unlimited" : "ótakmörkuðu",
-    "Verifying" : "Sannreyni",
-    "Personal info" : "Persónulegar upplýsingar",
-    "Sessions" : "Setur",
-    "App passwords" : "Lykilorð forrita",
-    "Sync clients" : "Samstilla biðlara",
+    "Developer documentation" : "Skjölun fyrir þróunaraðila",
+    "View in store" : "Skoða í hugbúnaðarsafni",
+    "Limit to groups" : "Takmarka við hópa",
+    "This app has an update available." : "Uppfærsla er tiltæk fyrir þetta forrit.",
+    "by %s" : "frá %s",
+    "%s-licensed" : "%s-notkunarleyfi",
+    "Documentation:" : "Hjálparskjöl:",
+    "User documentation" : "Hjálparskjöl notenda",
+    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
+    "Visit website" : "Heimsækja vefsvæðið",
+    "Report a bug" : "Tilkynna um villu",
+    "Show description …" : "Birta lýsingu …",
+    "Hide description …" : "Fela lýsingu …",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
+    "Enable only for specific groups" : "Einungis fyrir sérstaka hópa",
+    "SSL Root Certificates" : "SSL-rótarskilríki",
+    "Common Name" : "Almennt heiti",
+    "Valid until" : "Gildir til",
+    "Issued By" : "Gefið út af",
+    "Valid until %s" : "Gildir til %s",
+    "Import root certificate" : "Flytja inn rótarskilríki",
+    "Administrator documentation" : "Hjálparskjöl stjórnanda",
+    "Online documentation" : "Handbækur/skjölun á netinu",
+    "Forum" : "Vefspjall",
+    "Getting help" : "Til að fá hjálp",
+    "Commercial support" : "Gjaldskyld tækniaðstoð",
     "None" : "Ekkert",
     "Login" : "Innskráning",
     "Plain" : "Einfalt",
@@ -227,21 +249,21 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju.",
     "Start migration" : "Hefja yfirfærslu",
     "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu 'Ábendingar og góð ráð' (Tips & Tricks) og hjálparskjölin til að sjá ítarlegar upplýsingar.",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
-    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Tricks section and the documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu 'Ábendingar og góð ráð' (Tips & Tricks) og hjálparskjölin til að sjá ítarlegar upplýsingar.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
+    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
+    "%1$s below version %2$s is installed, for stability and performance reasons it is recommended to update to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
+    "The PHP module 'fileinfo' is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál. Skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a> til að sjá nánari upplýsingar.",
     "System locale can not be set to a one which supports UTF-8." : "Ekki var hægt að setja staðfærslu kerfisins á neina sem styður UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
+    "This means that there might be problems with certain characters in filenames." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
+    "It is strongly proposed to install the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
+    "If your installation is not installed at the root of the domain and uses system Cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%s\">annálnum</a>.",
     "All checks passed." : "Stóðst allar prófanir.",
     "Background jobs" : "Verk í bakgrunni",
@@ -250,10 +272,10 @@ OC.L10N.register(
     "Background job didn’t run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Til að ná bestum afköstum er mikilvægt að stilla bakgrunnsverk rétt. Fyrir stórar uppsetningar er mælt með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
     "Execute one task with each page loaded" : "Framkvæma eitt verk með hverri innhlaðinni síðu",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir http.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir HTTP.",
     "Use system cron service to call the cron.php file every 15 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 15 mínútna fresti.",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"%s\".",
-    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-posix-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
     "Version" : "Útgáfa",
     "Sharing" : "Deiling",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
@@ -286,34 +308,6 @@ OC.L10N.register(
     "Theming" : "Þemu",
     "Check the security of your Nextcloud over our security scan" : "Athugaðu öryggi Nextcloud-skýsins með öryggisskönnun okkar",
     "Hardening and security guidance" : "Brynjun og öryggisleiðbeiningar",
-    "Developer documentation" : "Skjölun fyrir þróunaraðila",
-    "View in store" : "Skoða í hugbúnaðarsafni",
-    "Limit to groups" : "Takmarka við hópa",
-    "This app has an update available." : "Uppfærsla er tiltæk fyrir þetta forrit.",
-    "by %s" : "frá %s",
-    "%s-licensed" : "%s-notkunarleyfi",
-    "Documentation:" : "Hjálparskjöl:",
-    "User documentation" : "Hjálparskjöl notenda",
-    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
-    "Visit website" : "Heimsækja vefsvæðið",
-    "Report a bug" : "Tilkynna um villu",
-    "Show description …" : "Birta lýsingu …",
-    "Hide description …" : "Fela lýsingu …",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
-    "Enable only for specific groups" : "Einungis fyrir sérstaka hópa",
-    "SSL Root Certificates" : "SSL-rótarskilríki",
-    "Common Name" : "Almennt heiti",
-    "Valid until" : "Gildir til",
-    "Issued By" : "Gefið út af",
-    "Valid until %s" : "Gildir til %s",
-    "Import root certificate" : "Flytja inn rótarskilríki",
-    "Administrator documentation" : "Hjálparskjöl stjórnanda",
-    "Online documentation" : "Handbækur/skjölun á netinu",
-    "Forum" : "Vefspjall",
-    "Getting help" : "Til að fá hjálp",
-    "Commercial support" : "Gjaldskyld tækniaðstoð",
     "You are using <strong>%s</strong> of <strong>%s</strong>" : "Þú notar <strong>%s</strong> af <strong>%s</strong>",
     "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "You are using <strong>%s</strong> af <strong>%s</strong> (<strong>%s %%</strong>)",
     "Profile picture" : "Einkennismynd",
@@ -340,23 +334,15 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Twitter handle @…" : "Twitter notandanafn @…",
     "You are member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
+    "Language" : "Tungumál",
+    "Help translate" : "Hjálpa við þýðingu",
     "Password" : "Lykilorð",
     "Current password" : "Núverandi lykilorð",
     "New password" : "Nýtt lykilorð",
     "Change password" : "Breyta lykilorði",
-    "Language" : "Tungumál",
-    "Help translate" : "Hjálpa við þýðingu",
-    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
-    "Desktop client" : "Skjáborðsforrit",
-    "Android app" : "Android-forrit",
-    "iOS app" : "iOS-forrit",
-    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ef þú vilt styðja við verkefnið {contributeopen}taktu þátt í þróuninni {linkclose} eða {contributeopen}láttu orð út ganga{linkclose}!",
-    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur",
     "Web, desktop and mobile clients currently logged in to your account." : "Veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
     "Device" : "Tæki",
     "Last activity" : "Síðasta virkni",
-    "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "Hér geturðu útbúið sérstök lykilorð fyrir hvert forrit svo að þú þurfir ekki að gefa upp lykilorðið þitt. Þú getur líka afturkallað þau hvert fyrir sig.",
-    "Name" : "Heiti",
     "App name" : "Heiti forrits",
     "Create new app password" : "Búa til nýtt lykilorð forrits",
     "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
@@ -364,11 +350,11 @@ OC.L10N.register(
     "Username" : "Notandanafn",
     "Done" : "Lokið",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
-    "Follow us on Google+!" : "Fylgstu með okkur á Google+!",
-    "Like our facebook page!" : "Líkaðu við Facebook-síðuna okkar!",
-    "Follow us on Twitter!" : "Fylgstu með okkur á Twitter!",
-    "Check out our blog!" : "Kíktu á bloggið okkar!",
-    "Subscribe to our newsletter!" : "Gerstu áskrifandi að fréttabréfinu okkar!",
+    "Follow us on Google+" : "Fylgstu með okkur á Google+",
+    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
+    "Follow us on Twitter" : "Fylgstu með okkur á Twitter",
+    "Check out our blog" : "Kíktu á bloggið okkar",
+    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
     "Settings" : "Stillingar",
     "Show storage location" : "Birta staðsetningu gagnageymslu",
     "Show user backend" : "Birta bakenda notanda",
@@ -386,6 +372,7 @@ OC.L10N.register(
     "Disabled" : "Óvirkt",
     "Default quota" : "Sjálfgefinn kvóti",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Settu inn geymslukvóta (t.d.: \"512 MB\" eða \"12 GB\")",
+    "Unlimited" : "ótakmörkuðu",
     "Other" : "Annað",
     "Group admin for" : "Hópstjóri fyrir",
     "Quota" : "Kvóti",
@@ -401,6 +388,7 @@ OC.L10N.register(
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
     "test email settings" : "prófa tölvupóststillingar",
+    "Invalid request" : "Ógild fyrirspurn",
     "Admins can't remove themself from the admin group" : "Stjórnendur geta ekki fjarlægt sjálfa sig úr stjórnendahóp",
     "Unable to add user to group %s" : "Ekki tókst að bæta notanda við hópinn %s",
     "Unable to remove user from group %s" : "Ekki tókst að fjarlægja notanda úr hópnum %s",
@@ -408,13 +396,28 @@ OC.L10N.register(
     "Uninstalling ...." : "Tek út uppsetningu ....",
     "Error while uninstalling app" : "Villa við að fjarlægja forrit",
     "Uninstall" : "Henda út",
+    "__language_name__" : "Íslenska",
+    "Personal info" : "Persónulegar upplýsingar",
+    "Sessions" : "Setur",
+    "App passwords" : "Lykilorð forrita",
+    "Sync clients" : "Samstilla biðlara",
     "This is used for sending out notifications." : "Þetta er notað til að senda út tilkynningar.",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
+    "This means that there might be problems with certain characters in file names." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
     "Cron" : "CRON",
     "Last cron job execution: %s." : "Síðasta keyrsla cron-verks: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Síðasta keyrsla cron-verks: %s. Eitthvað er ekki eins og það á að sér að vera.",
     "Cron was not executed yet!" : "Cron hefur ekki ennþá verið keyrt!",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 15 mínútna fresti.",
+    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-posix-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
     "Uninstall app" : "Henda út forriti",
     "Hey there,<br><br>just letting you know that you now have a %s account.<br><br>Your username: <strong>%s</strong><br>Access it: <strong><a href=\"%s\">%s</a></strong><br><br>" : "Hæ þú,<br><br>bara að láta þig vita að þú átt núna s aðgang.<br><br>Notandanafnið þitt: <strong>%s</strong><br>Tengstu honum: <strong><a href=\"%s\">%s</a></strong><br><br>",
     "Cheers!" : "Til hamingju!",
@@ -422,10 +425,27 @@ OC.L10N.register(
     "For password recovery and notifications" : "Fyrir tilkynningar og endurheimtingu lykilorðs",
     "Your website" : "Vefsvæðið þitt",
     "Your Twitter handle" : "Twitter notandanafnið þitt",
+    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
+    "Desktop client" : "Skjáborðsforrit",
+    "Android app" : "Android-forrit",
+    "iOS app" : "iOS-forrit",
+    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ef þú vilt styðja við verkefnið {contributeopen}taktu þátt í þróuninni {linkclose} eða {contributeopen}láttu orð út ganga{linkclose}!",
+    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur",
     "Passcodes that give an app or device permissions to access your account." : "Aðgangskóði sem gefur forriti eða tæki heimild til að nota notandaaðganginn þinn.",
+    "Name" : "Heiti",
     "Follow us on Google Plus!" : "Fylgstu með okkur á Google Plus!",
+    "Like our facebook page!" : "Líkaðu við Facebook-síðuna okkar!",
     "Subscribe to our twitter channel!" : "Gerstu áskrifandi að twitter-rásinni okkar!",
     "Subscribe to our news feed!" : "Gerstu áskrifandi að fréttastraumi okkar!",
-    "Show last log in" : "Birta síðustu innskráningu"
+    "Subscribe to our newsletter!" : "Gerstu áskrifandi að fréttabréfinu okkar!",
+    "Show last log in" : "Birta síðustu innskráningu",
+    "Verifying" : "Sannreyni",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu 'Ábendingar og góð ráð' (Tips & Tricks) og hjálparskjölin til að sjá ítarlegar upplýsingar.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
+    "Web, desktop, mobile clients and app specific passwords that currently have access to your account." : "Veftól, tölvur, símar og sértæk lykilorð forrita sem núna hafa aðgang inn á aðganginn þinn.",
+    "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "Hér geturðu útbúið sérstök lykilorð fyrir hvert forrit svo að þú þurfir ekki að gefa upp lykilorðið þitt. Þú getur líka afturkallað þau hvert fyrir sig.",
+    "Follow us on Google+!" : "Fylgstu með okkur á Google+!",
+    "Follow us on Twitter!" : "Fylgstu með okkur á Twitter!",
+    "Check out our blog!" : "Kíktu á bloggið okkar!"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
